@@ -135,8 +135,8 @@ use SVN::Client;
 use Readonly;
 use YAML::AppConfig;
 use Youri::Package::RPM 0.002;
-use version; our $VERSION = qv('0.6.2');
-use feature qw/switch/;
+use version; our $VERSION = qv('0.6.3');
+use experimental qw/switch/;
 
 # default values
 Readonly::Scalar my $defaults => <<'EOF';
@@ -809,7 +809,7 @@ sub _get_new_version {
 
     return unless $line =~ /^
         (
-            %define \s+              # macro
+            %(?:define|global) \s+   # macro
                 (?:
                     version
                 |
@@ -835,7 +835,7 @@ sub _get_new_release {
 
     return unless $line =~ /^
     (
-        %define \s+      # macro
+        %(?:define|global) \s+      # macro
             (?:
                 rel
             |
@@ -857,7 +857,7 @@ sub _get_new_release {
             my ($macro_name, $macro_spacing, $macro_value) = ($1, $2, $3);
             $macro_value = _get_new_release_number($macro_value, $new_version, $release_suffix);
             $value = '%' . $macro_name . $macro_spacing . $macro_value;
-        } elsif ($value =~ /^% { (\w+) (\s+) (\S+) } $/x) {
+        } elsif ($value =~ /^% \{ (\w+) (\s+) (\S+) \} $/x) {
             my ($macro_name, $macro_spacing, $macro_value) = ($1, $2, $3);
             $macro_value = _get_new_release_number($macro_value, $new_version, $release_suffix);
             $value = '%{' . $macro_name . $macro_spacing . $macro_value . '}';
